@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0107';
+our $VERSION = '0.0108';
 
 use strict;
 use warnings;
@@ -63,10 +63,7 @@ sub transform {
     $variation //= 0;
     my $pitches = $self->chords->{ 'C' . $chord_name }[$variation];
     my $diff = $target - _lowest_c($pitches);
-    my @notes;
-    for my $pitch (@$pitches) {
-        push @notes, $pitch + $diff;
-    }
+    my @notes = map { $_ + $diff } @$pitches;
     return \@notes;
 }
 
@@ -106,7 +103,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0107
+version 0.0108
 
 =head1 SYNOPSIS
 
@@ -114,6 +111,8 @@ version 0.0107
 
   my $mcg = MIDI::Chord::Guitar->new;
 
+  my $voicings = $mcg->voicings('dim7');
+
   my $chord = $mcg->transform('D3', 'dim7', 0);
 
   # MIDI:
@@ -202,7 +201,7 @@ diagrams to figure out the exact neck positions.
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> file in this distribution
+The F<t/01-methods.t> and F<eg/autumn_leaves> files in this distribution
 
 L<File::ShareDir>
 
